==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/enums/CategoryColor.java <==
package odata.msgraph.client.beta.enums;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.github.davidmoten.odata.client.Enum;

public enum CategoryColor implements Enum {

    @JsonProperty("preset0")
    PRESET0("preset0", "0"),

    @JsonProperty("preset1")
    PRESET1("preset1", "1"),

    @JsonProperty("preset2")
    PRESET2("preset2", "2"),

    @JsonProperty("preset3")
    PRESET3("preset3", "3"),

    @JsonProperty("preset4")
    PRESET4("preset4", "4"),

    @JsonProperty("preset5")
    PRESET5("preset5", "5"),

    @JsonProperty("preset6")
    PRESET6("preset6", "6"),

    @JsonProperty("preset7")
    PRESET7("preset7", "7"),

    @JsonProperty("preset8")
    PRESET8("preset8", "8"),

    @JsonProperty("preset9")
    PRESET9("preset9", "9"),

    @JsonProperty("preset10")
    PRESET10("preset10", "10"),

    @JsonProperty("preset11")
    PRESET11("preset11", "11"),

    @JsonProperty("preset12")
    PRESET12("preset12", "12"),

    @JsonProperty("preset13")
    PRESET13("preset13", "13"),

    @JsonProperty("preset14")
    PRESET14("preset14", "14"),

    @JsonProperty("preset15")
    PRESET15("preset15", "15"),

    @JsonProperty("preset16")
    PRESET16("preset16", "16"),

    @JsonProperty("preset17")
    PRESET17("preset17", "17"),

    @JsonProperty("preset18")
    PRESET18("preset18", "18"),

    @JsonProperty("preset19")
    PRESET19("preset19", "19"),

    @JsonProperty("preset20")
    PRESET20("preset20", "20"),

    @JsonProperty("preset21")
    PRESET21("preset21", "21"),

    @JsonProperty("preset22")
    PRESET22("preset22", "22"),

    @JsonProperty("preset23")
    PRESET23("preset23", "23"),

    @JsonProperty("preset24")
    PRESET24("preset24", "24"),

    @JsonProperty("none")
    NONE("none", "-1");

    private final String name;
    private final String value;

    private CategoryColor(String name, String value) {
        this.name = name;
        this.value = value;
    }

    @Override
    public String enumName() {
        return name;
    }

    @Override
    public String enumValue() {
        return value;
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/enums/CategoryColor.java <==
package odata.msgraph.client.beta.enums;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.github.davidmoten.odata.client.Enum;

import java.lang.Override;
import java.lang.String;

public enum CategoryColor implements Enum {

    @JsonProperty("none")
    NONE("none", "-1"),

    @JsonProperty("preset0")
    PRESET0("preset0", "0"),

    @JsonProperty("preset1")
    PRESET1("preset1", "1"),

    @JsonProperty("preset2")
    PRESET2("preset2", "2"),

    @JsonProperty("preset3")
    PRESET3("preset3", "3"),

    @JsonProperty("preset4")
    PRESET4("preset4", "4"),

    @JsonProperty("preset5")
    PRESET5("preset5", "5"),

    @JsonProperty("preset6")
    PRESET6("preset6", "6"),

    @JsonProperty("preset7")
    PRESET7("preset7", "7"),

    @JsonProperty("preset8")
    PRESET8("preset8", "8"),

    @JsonProperty("preset9")
    PRESET9("preset9", "9"),

    @JsonProperty("preset10")
    PRESET10("preset10", "10"),

    @JsonProperty("preset11")
    PRESET11("preset11", "11"),

    @JsonProperty("preset12")
    PRESET12("preset12", "12"),

    @JsonProperty("preset13")
    PRESET13("preset13", "13"),

    @JsonProperty("preset14")
    PRESET14("preset14", "14"),

    @JsonProperty("preset15")
    PRESET15("preset15", "15"),

    @JsonProperty("preset16")
    PRESET16("preset16", "16"),

    @JsonProperty("preset17")
    PRESET17("preset17", "17"),

    @JsonProperty("preset18")
    PRESET18("preset18", "18"),

    @JsonProperty("preset19")
    PRESET19("preset19", "19"),

    @JsonProperty("preset20")
    PRESET20("preset20", "20"),

    @JsonProperty("preset21")
    PRESET21("preset21", "21"),

    @JsonProperty("preset22")
    PRESET22("preset22", "22"),

    @JsonProperty("preset23")
    PRESET23("preset23", "23"),

    @JsonProperty("preset24")
    PRESET24("preset24", "24");

    private final String name;
    private final String value;

    private CategoryColor(String name, String value) {
        this.name = name;
        this.value = value;
    }

    @Override
    public String enumName() {
        return name;
    }

    @Override
    public String enumValue() {
        return value;
    }

}
